@@ -4,13 +4,13 @@ from django.contrib.admin.options import TO_FIELD_VAR
 from django.contrib.admin.utils import unquote
 from django.http import HttpResponseRedirect
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _, ungettext_lazy
+from django.utils.translation import gettext_lazy as _
 
-from model_clone import CloneMixin
+from model_clone.mixins.clone import CloneMixin
 
 
-class CloneModelAdmin(ModelAdmin):
-    """Admin to handle duplication of models."""
+class CloneModelAdminMixin(object):
+    """Mixin to handle duplication of models."""
 
     include_duplicate_action = True
     include_duplicate_object_link = True
@@ -60,10 +60,7 @@ class CloneModelAdmin(ModelAdmin):
                 _("Successfully created: {} new duplicates".format(len(clone_obj_ids))),
             )
 
-    make_clone.short_description = ungettext_lazy(
-        "Duplicate selected %(verbose_name)s",
-        "Duplicate selected %(verbose_name_plural)s",
-    )
+    make_clone.short_description = _("Duplicate selected %(verbose_name_plural)s")
 
     def _get_base_actions(self):
         """Return the list of actions, prior to any request-based filtering."""
@@ -73,3 +70,7 @@ class CloneModelAdmin(ModelAdmin):
             actions.extend(self.get_action(action) for action in ["make_clone"])
 
         return actions
+
+
+class CloneModelAdmin(CloneModelAdminMixin, ModelAdmin):
+    """Clone model admin view."""
